package net.p0f.k8s.demo.apiclient;

import java.io.IOException;

import org.jboss.logging.Logger;

import jakarta.ws.rs.client.ClientRequestContext;
import jakarta.ws.rs.client.ClientResponseContext;
import jakarta.ws.rs.client.ClientResponseFilter;

public class ResponseFilter implements ClientResponseFilter {
    final Logger LOG = Logger.getLogger(ResponseFilter.class.getName());

    @Override
    public void filter(ClientRequestContext requestContext, ClientResponseContext responseContext) throws IOException {
        // Log request info first.
        LOG.info("Original request: " + requestContext.getMethod() + " " + requestContext.getUri());
        LOG.info("Request Headers:");
        requestContext.getHeaders().forEach((k, v) -> {
            LOG.info(k + ": " + v);
        });
        if (requestContext.getEntity() != null) {
            LOG.info("Request payload:");
            LOG.info(requestContext.getEntity().toString());
        } else {
            LOG.info("Request payload empty.");
        }

        // If status wasn't a happy one, reset it and add a header with the original.
        // The Activator will do the rest of response processing.
        if (responseContext.getStatus() > 299) {
            responseContext.getHeaders().add("X-Original-Status", String.valueOf(responseContext.getStatus()));
            responseContext.setStatus(200);
        }
    }
}
